@@ -16,6 +16,7 @@ SV* char_from_k(K);
 SV* short_from_k(K);
 SV* int_from_k(K);
 SV* long_from_k(K);
+SV* timestamp_from_k(K);
 SV* real_from_k(K);
 SV* float_from_k(K);
 SV* symbol_from_k(K);
@@ -27,6 +28,7 @@ SV* byte_vector_from_k(K);
 SV* short_vector_from_k(K);
 SV* int_vector_from_k(K);
 SV* long_vector_from_k(K);
+SV* timestamp_vector_from_k(K);
 SV* real_vector_from_k(K);
 SV* float_vector_from_k(K);
 SV* symbol_vector_from_k(K);
