@@ -1,6 +1,6 @@
 package K::Raw;
 BEGIN {
-    $K::Raw::VERSION = '0.05';
+    $K::Raw::VERSION = '0.06';
 }
 use strict;
 use warnings;
@@ -36,6 +36,12 @@ K::Raw - Low-level Perl bindings for k (aka q, aka kdb, aka kx)
 
     k($handle, q/2012.03.24D12:13:14.15161728/); # '385906394151617280'
 
+    # execute cmd asynchrounously
+    k(-$handle, q/.u.upd[`t;(`foo;1.23)]/);
+
+    # read an incoming message
+    my $msg = k($handle);
+
     kclose($handle);
 
 =head1 DESCRIPTION
